@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,10 +7,11 @@
 #ifndef COLLECTIONEXPIRYJOB_H
 #define COLLECTIONEXPIRYJOB_H
 
-#include <QObject>
 #include <AkonadiCore/Collection>
+#include <QObject>
 class KJob;
-namespace MailCommon {
+namespace MailCommon
+{
 class CollectionExpiryJob : public QObject
 {
     Q_OBJECT
