@@ -1,13 +1,13 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "collectiontemplateswidget.h"
 
-#include <KLocalizedString>
 #include "templatesconfiguration_kfg.h"
+#include <KLocalizedString>
 
 #include <MailCommon/FolderSettings>
 #include <QCheckBox>
@@ -18,8 +18,8 @@ using namespace MailCommon;
 CollectionTemplatesWidget::CollectionTemplatesWidget(QWidget *parent)
     : QWidget(parent)
 {
-    auto *topLayout = new QVBoxLayout(this);
-    auto *topItems = new QHBoxLayout;
+    auto topLayout = new QVBoxLayout(this);
+    auto topItems = new QHBoxLayout;
     topItems->setContentsMargins(0, 0, 0, 0);
     topLayout->addLayout(topItems);
 
@@ -38,8 +38,8 @@ CollectionTemplatesWidget::CollectionTemplatesWidget(QWidget *parent)
 
     topLayout->addWidget(mWidget);
 
-    auto *btns = new QHBoxLayout();
-    QPushButton *copyGlobal = new QPushButton(i18n("&Copy Global Templates"), this);
+    auto btns = new QHBoxLayout();
+    auto copyGlobal = new QPushButton(i18n("&Copy Global Templates"), this);
     copyGlobal->setEnabled(false);
     btns->addWidget(copyGlobal);
     topLayout->addLayout(btns);
@@ -61,7 +61,7 @@ void CollectionTemplatesWidget::save(Akonadi::Collection &col)
     }
     if (mChanged) {
         TemplateParser::Templates t(mCollectionId);
-        //qCDebug(KMAIL_LOG) << "use custom templates for folder" << fid <<":" << mCustom->isChecked();
+        // qCDebug(KMAIL_LOG) << "use custom templates for folder" << fid <<":" << mCustom->isChecked();
         t.setUseCustomTemplates(mCustom->isChecked());
         t.save();
 
