@@ -12,10 +12,7 @@
 class GPGHelper
 {
 public:
-    enum CryptoType {
-        OpenPGP,
-        SMIME
-    };
+    enum CryptoType { OpenPGP, SMIME };
 
     explicit GPGHelper(const QString &templateGnupgHome);
     ~GPGHelper();
