@@ -51,7 +51,7 @@ FilterAction::ReturnCode FilterActionAddToAddressBook::process(ItemContext &cont
         return ErrorButGoOn;
     }
 
-    const KMime::Message::Ptr msg = context.item().payload<KMime::Message::Ptr>();
+    const auto msg = context.item().payload<KMime::Message::Ptr>();
 
     QString headerLine;
     switch (mHeaderType) {
@@ -255,11 +255,7 @@ QString FilterActionAddToAddressBook::argsAsString() const
 
 void FilterActionAddToAddressBook::argsFromString(const QString &argsStr)
 {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    const QStringList parts = argsStr.split(QLatin1Char('\t'), QString::KeepEmptyParts);
-#else
     const QStringList parts = argsStr.split(QLatin1Char('\t'), Qt::KeepEmptyParts);
-#endif
     const QString firstElement = parts[0];
     if (firstElement == QLatin1String("From")) {
         mHeaderType = FromHeader;
