@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,7 +13,8 @@
 
 class QFile;
 
-namespace MailCommon {
+namespace MailCommon
+{
 class MailFilter;
 
 class FilterImporterProcmail : public FilterImporterAbstract
