@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
@@ -14,7 +14,7 @@ class SnippetWidgetTest : public QObject
     Q_OBJECT
 public:
     explicit SnippetWidgetTest(QObject *parent = nullptr);
-    ~SnippetWidgetTest() = default;
+    ~SnippetWidgetTest() override = default;
 private Q_SLOTS:
     void shouldHaveDefaultValues();
     void shouldClearWidget();
